@@ -16,7 +16,7 @@
 
 #include <EventViews/CalendarDecoration>
 
-namespace KIdentityManagement
+namespace KIdentityManagementCore
 {
 class IdentityManager;
 }
@@ -28,7 +28,7 @@ public:
 
     static KOCore *self();
 
-    Q_REQUIRED_RESULT QVector<KPluginMetaData> availableCalendarDecorations();
+    [[nodiscard]] QList<KPluginMetaData> availableCalendarDecorations();
 
     EventViews::CalendarDecoration::Decoration *loadCalendarDecoration(const KPluginMetaData &service);
     EventViews::CalendarDecoration::Decoration::List loadCalendarDecorations();
@@ -41,7 +41,7 @@ public:
 
     void reloadPlugins();
 
-    KIdentityManagement::IdentityManager *identityManager();
+    KIdentityManagementCore::IdentityManager *identityManager();
 
 protected:
     KOCore();
