@@ -18,25 +18,13 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KCMApptSummary, "kcmapptsummary.json")
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KCMApptSummary::KCMApptSummary(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , mDaysButtonGroup(new QButtonGroup(this)) // krazy:exclude=tipsandthis
-    , mShowButtonGroup(new QButtonGroup(this)) // krazy:exclude=tipsandthis
-    , mGroupwareButtonGroup(new QButtonGroup(this)) // krazy:exclude=tipsandthis
-#else
-KCMApptSummary::KCMApptSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KCMApptSummary::KCMApptSummary(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , mDaysButtonGroup(new QButtonGroup(widget())) // krazy:exclude=tipsandthis
     , mShowButtonGroup(new QButtonGroup(widget())) // krazy:exclude=tipsandthis
     , mGroupwareButtonGroup(new QButtonGroup(widget())) // krazy:exclude=tipsandthis
-#endif
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    setupUi(this);
-#else
     setupUi(widget());
-#endif
 
     mDaysButtonGroup->addButton(mDateTodayButton, 0);
     mDaysButtonGroup->addButton(mDateMonthButton, 1);
@@ -61,22 +49,14 @@ KCMApptSummary::KCMApptSummary(QObject *parent, const KPluginMetaData &data, con
     connect(mCustomDays, &QSpinBox::valueChanged, this, &KCMApptSummary::modified);
     connect(mCustomDays, &QSpinBox::valueChanged, this, &KCMApptSummary::customDaysChanged);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    KAcceleratorManager::manage(this);
-#else
     KAcceleratorManager::manage(widget());
-#endif
 
     load();
 }
 
 void KCMApptSummary::modified()
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     markAsChanged();
-#endif
 }
 
 void KCMApptSummary::buttonClicked(QAbstractButton *button)
@@ -94,7 +74,7 @@ void KCMApptSummary::customDaysChanged(int value)
 void KCMApptSummary::load()
 {
     KConfig config(QStringLiteral("kcmapptsummaryrc"));
-    KConfigGroup group = config.group("Days");
+    KConfigGroup group = config.group(QStringLiteral("Days"));
 
     int days = group.readEntry("DaysToShow", 7);
     if (days == 1) {
@@ -107,25 +87,21 @@ void KCMApptSummary::load()
         mCustomDays->setEnabled(true);
     }
 
-    group = config.group("Show");
+    group = config.group(QStringLiteral("Show"));
 
     mShowBirthdaysFromCal->setChecked(group.readEntry("BirthdaysFromCalendar", true));
     mShowAnniversariesFromCal->setChecked(group.readEntry("AnniversariesFromCalendar", true));
 
-    group = config.group("Groupware");
+    group = config.group(QStringLiteral("Groupware"));
     mShowMineOnly->setChecked(group.readEntry("ShowMineOnly", false));
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void KCMApptSummary::save()
 {
     KConfig config(QStringLiteral("kcmapptsummaryrc"));
-    KConfigGroup group = config.group("Days");
+    KConfigGroup group = config.group(QStringLiteral("Days"));
 
     int days;
     switch (mDaysButtonGroup->checkedId()) {
@@ -143,19 +119,15 @@ void KCMApptSummary::save()
 
     group.writeEntry("DaysToShow", days);
 
-    group = config.group("Show");
+    group = config.group(QStringLiteral("Show"));
     group.writeEntry("BirthdaysFromCalendar", mShowBirthdaysFromCal->isChecked());
     group.writeEntry("AnniversariesFromCalendar", mShowAnniversariesFromCal->isChecked());
 
-    group = config.group("Groupware");
+    group = config.group(QStringLiteral("Groupware"));
     group.writeEntry("ShowMineOnly", mShowMineOnly->isChecked());
 
     config.sync();
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void KCMApptSummary::defaults()
@@ -169,11 +141,9 @@ void KCMApptSummary::defaults()
 
     mShowMineOnly->setChecked(false);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     markAsChanged();
-#endif
 }
 
 #include "kcmapptsummary.moc"
+
+#include "moc_kcmapptsummary.cpp"
