@@ -15,6 +15,7 @@
 #include "korganizer.h"
 #include "actionmanager.h"
 #include "calendarview.h"
+#include "config-korganizer.h"
 #include "impl/korganizerifaceimpl.h"
 #include "kocore.h"
 #include "plugininterface/korganizerplugininterface.h"
@@ -54,7 +55,7 @@ KOrganizer::KOrganizer()
     mainWidgetLayout->setContentsMargins({});
     mainWidgetLayout->setSpacing(0);
     if (PimCommon::NeedUpdateVersionUtils::checkVersion()) {
-        const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(KAboutData::applicationData().version(), QDate::currentDate());
+        const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(QLatin1String(KORGANIZER_RELEASE_VERSION_DATE), QDate::currentDate());
         if (status != PimCommon::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
             auto needUpdateVersionWidget = new PimCommon::NeedUpdateVersionWidget(this);
             mainWidgetLayout->addWidget(needUpdateVersionWidget);
