@@ -29,11 +29,7 @@ class KOrganizerPart : public KParts::ReadOnlyPart, public KOrg::MainWindow
 {
     Q_OBJECT
 public:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    explicit KOrganizerPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
-#else
     explicit KOrganizerPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData &data, const QVariantList &);
-#endif
     ~KOrganizerPart() override;
 
     KOrg::CalendarViewBase *view() const override;
@@ -47,16 +43,16 @@ public:
 
       @return true on success, false if an error occurred
     */
-    Q_REQUIRED_RESULT bool openURL(const QUrl &url, bool merge = false) override;
+    [[nodiscard]] bool openURL(const QUrl &url, bool merge = false) override;
 
     /** Save calendar file to URL of current calendar */
-    Q_REQUIRED_RESULT bool saveURL() override;
+    [[nodiscard]] bool saveURL() override;
 
     /** Save calendar file to URL */
-    Q_REQUIRED_RESULT bool saveAsURL(const QUrl &url) override;
+    [[nodiscard]] bool saveAsURL(const QUrl &url) override;
 
     /** Get current URL */
-    Q_REQUIRED_RESULT QUrl getCurrentURL() const override;
+    [[nodiscard]] QUrl getCurrentURL() const override;
 
     KXMLGUIFactory *mainGuiFactory() override
     {
