@@ -8,7 +8,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include "kprefsdialog.h"
 #include <QWidget>
 
@@ -23,11 +22,7 @@ class KOPrefsDialogColorsAndFonts : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KOPrefsDialogColorsAndFonts(QWidget *parent, const QVariantList &args = {});
-#else
-    explicit KOPrefsDialogColorsAndFonts(QObject *parent, const KPluginMetaData &data, const QVariantList &args = {});
-#endif
+    explicit KOPrefsDialogColorsAndFonts(QObject *parent, const KPluginMetaData &data);
 
 protected:
     void usrWriteConfig() override;
