@@ -8,7 +8,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include <KCModule>
 
 #ifdef WITH_KUSERFEEDBACK
@@ -19,11 +18,7 @@ class FeedbackConfigWidget;
 class KOPrefsUserFeedBack : public KCModule
 {
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KOPrefsUserFeedBack(QWidget *parent, const QVariantList &args = {});
-#else
-    explicit KOPrefsUserFeedBack(QObject *parent, const KPluginMetaData &data, const QVariantList &args = {});
-#endif
+    explicit KOPrefsUserFeedBack(QObject *parent, const KPluginMetaData &data);
 
 protected:
     void load() override;
